@@ -26,6 +26,29 @@ class MrsClient(AbstractClient):
     _service = 'mrs'
 
 
+    def DrugInstructionObject(self, request):
+        """药品说明书PDF文件结构化
+
+        :param request: Request instance for DrugInstructionObject.
+        :type request: :class:`tencentcloud.mrs.v20200910.models.DrugInstructionObjectRequest`
+        :rtype: :class:`tencentcloud.mrs.v20200910.models.DrugInstructionObjectResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DrugInstructionObject", params, headers=headers)
+            response = json.loads(body)
+            model = models.DrugInstructionObjectResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ImageMask(self, request):
         """医疗报告图片脱敏接口
 
@@ -49,6 +72,52 @@ class MrsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ImageMaskAsync(self, request):
+        """图片脱敏-异步接口
+
+        :param request: Request instance for ImageMaskAsync.
+        :type request: :class:`tencentcloud.mrs.v20200910.models.ImageMaskAsyncRequest`
+        :rtype: :class:`tencentcloud.mrs.v20200910.models.ImageMaskAsyncResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ImageMaskAsync", params, headers=headers)
+            response = json.loads(body)
+            model = models.ImageMaskAsyncResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ImageMaskAsyncGetResult(self, request):
+        """图片脱敏-异步获取结果接口
+
+        :param request: Request instance for ImageMaskAsyncGetResult.
+        :type request: :class:`tencentcloud.mrs.v20200910.models.ImageMaskAsyncGetResultRequest`
+        :rtype: :class:`tencentcloud.mrs.v20200910.models.ImageMaskAsyncGetResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ImageMaskAsyncGetResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.ImageMaskAsyncGetResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ImageToClass(self, request):
         """图片分类
 
@@ -98,6 +167,8 @@ class MrsClient(AbstractClient):
     def TextToClass(self, request):
         """文本分类
 
+        适用场景：经过腾讯医疗专用 OCR 从图片识别之后的文本，并且需要加上每个字符的坐标信息，才可以调用此接口。通过其它 OCR 识别的文本可能不适配。医院的 XML 格式文本也不适配，XML 文件需要经过特殊转换才能直接调用此接口。单次调用传入的文本不宜超过 2000 字。如有需要调用此接口，建议先咨询产品团队。
+
         :param request: Request instance for TextToClass.
         :type request: :class:`tencentcloud.mrs.v20200910.models.TextToClassRequest`
         :rtype: :class:`tencentcloud.mrs.v20200910.models.TextToClassResponse`
